# -*- coding: utf-8 -*-
"""
    ml_autp_scikit_learn
    ~~~~~~~~~~~~~~~~~~~~

    Demonstration of ML using Auto ML
    A binary classification problem: Predict whether student will have a grade better then C or not

    :author: Jiri Spilka, 2019
"""

import numpy as np

from sklearn.metrics import accuracy_score, confusion_matrix
import autosklearn.classification

import utils

df = utils.load_data_binary()

# create train (years 15, 16, 17) and test dataset (18)
df_train = df.loc[df['year'] < 2018, :]
df_test = df.loc[df['year'] == 2018, :]

X_train = df_train.loc[:, ['points_st1', 'points_st2']].astype(np.float).values
X_test = df_test.loc[:, ['points_st1', 'points_st2']].astype(np.float).values
y_train = df_train['y'].values
y_test = df_test['y'].values

print(f"training set {len(X_train)}, #y==0: {sum(y_train == 0)} #y==1: {sum(y_train == 1)}")
print(f"test set     {len(X_test)}, #y==0: {sum(y_test == 0)} #y==1: {sum(y_test == 1)}")

automl = autosklearn.classification.AutoSklearnClassifier(
    time_left_for_this_task=60,
    exclude_estimators=None,
    include_preprocessors=["no_preprocessing"],
    exclude_preprocessors=None,
    ensemble_size=1
)
automl.fit(X_train, y_train, dataset_name="exam_prediction")

print(automl.show_models())
print(automl.sprint_statistics())


# predict on a test data
y_test_pred = automl.predict(X_test)

acc = accuracy_score(y_true=y_test, y_pred=y_test_pred)
cm = confusion_matrix(y_true=y_test, y_pred=y_test_pred)

print(f"\nAccuracy: {acc}")
print(f"Confusion matrix: \n {cm}")

